Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StreamServerInterceptor ¶
func StreamServerInterceptor(funcs ...ErrorHandlerFunc) grpc.StreamServerInterceptor
StreamServerInterceptor returns a new streaming server interceptor to handle errors
func UnaryServerInterceptor ¶
func UnaryServerInterceptor(funcs ...ErrorHandlerFunc) grpc.UnaryServerInterceptor
UnaryServerInterceptor returns a new unary server interceptor to handle errors
Types ¶
type AppErrorHandlerFunc ¶
AppErrorHandlerFunc is a function that called by interceptors when specified application erorrs are detected.
type ErrorHandlerFunc ¶
ErrorHandlerFunc is a function that called by interceptors when specified erorrs are detected.
func WithNotWrappedErrorHandler ¶
func WithNotWrappedErrorHandler(f ErrorHandlerFunc) ErrorHandlerFunc
WithNotWrappedErrorHandler returns a new error handler function for handling not wrapped errors.
func WithReportableErrorHandler ¶
func WithReportableErrorHandler(f AppErrorHandlerFunc) ErrorHandlerFunc
WithReportableErrorHandler returns a new error handler function for handling errors annotated with the reportability.
func WithStatusCodeMapper ¶
func WithStatusCodeMapper(m map[int]codes.Code) ErrorHandlerFunc
WithStatusCodeMapper returns a new error handler function for mapping status codes to gRPC's one.